tiled.structures.array.BuiltinDtype
===================================

.. currentmodule:: tiled.structures.array

.. autoclass:: BuiltinDtype

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~BuiltinDtype.__init__
      ~BuiltinDtype.from_json
      ~BuiltinDtype.from_numpy_dtype
      ~BuiltinDtype.to_numpy_dtype
      ~BuiltinDtype.to_numpy_str
   
   

   
   
   